==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ru.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календарь",
    "%s has published the calendar \"%s\"" : "%s опубликовал календарь \"%s\"",
    "Too many redirects. Aborting ..." : "Очень много перенаправлений. Отмена...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Удалённый сервер не предоставил нам доступ к календарю (ошибка HTTP {%s})",
    "Error connecting to remote server" : "Ошибка подключения к удаленному серверу",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ошибка запроса ресурса на удаленном сервере. Это может  быть связано с несовпадением сертификата.",
    "Error requesting resource on remote server" : "Ошибка запроса ресурса на удалённом сервере",
    "Individual" : "Личность",
    "Group" : "Группа",
    "Resource" : "Ресурс",
    "Room" : "Комната",
    "Unknown" : "Неизвестно",
    "Required" : "Обязательно",
    "Optional" : "Не обязательно",
    "Does not attend" : "Без посещения",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вы находитесь в неизвестном часовом поясе ({tz}), возвращаемся к UTC",
    "Please create a calendar first." : "Пожалуйста, создайте сначала календарь.",
    "New event" : "Новое событие",
    "CalDAV address for clients" : "Адрес CalDAV  для клиентов",
    "Error saving WebCal-calendar" : "Ошибка при сохранении календаря WebCal",
    "WebDAV address for subscriptions" : "Адрес WebDAV для подписок",
    "EMail has been sent." : "E-mail был отправлен.",
    "There was an issue while sending your EMail." : "Произошла ошибка при отправке вашего сообщения.",
    "group" : "группа",
    "Details" : "Подробно",
    "Attendees" : "Участники",
    "Reminders" : "Напоминания",
    "Repeating" : "Повторение",
    "When shared show full event" : "Показывать подробно при размещении в общем доступе",
    "When shared show only busy" : "Показывать только занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "Confirmed" : "Подтверждено",
    "Tentative" : "Под вопросом",
    "Cancelled" : "Отменено",
    "Please add a title!" : "Пожалуйста добавьте заголовок!",
    "Please select a calendar!" : "Пожалуйста выберите календарь!",
    "The event ends before it starts!" : "Окончание раньше начала!",
    "Global" : "Основные",
    "None" : "Отсутствует",
    "Every day" : "Каждый день",
    "Every week" : "Каждую неделю",
    "Every month" : "Каждый месяц",
    "Every year" : "Каждый год",
    "never" : "никогда",
    "after" : "после",
    "How about getting started by importing some calendars?" : "Начнем с импорта календарей?",
    "At time of event" : "Во время события",
    "5 minutes before" : "За 5 минут до начала",
    "10 minutes before" : "За 10 минут до начала",
    "15 minutes before" : "За 15 минут до начала",
    "30 minutes before" : "За 30 минут до начала",
    "1 hour before" : "За 1 час до начала",
    "2 hours before" : "За 2 часа до начала",
    "Custom" : "Свои настройки",
    "Audio" : "Звук",
    "E Mail" : "По e-mail",
    "Pop up" : "Всплывающее окно",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "часов",
    "days" : "дней",
    "week" : "неделя",
    "before" : "до",
    "start" : "начала",
    "end" : "окончания",
    "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Successfully imported" : "Успешно импортировано",
    "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
    "Partially imported, {n} failures" : "Частично импортировано, {n} ошибок",
    "Audio alarm" : "Звуковой сигнал",
    "Pop-up" : "Всплывающее окно",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} до начала события",
    "{type} {time} before the event ends" : "{type} {time} до окончания события",
    "{type} {time} after the event starts" : "{type} {time} после начала события",
    "{type} {time} after the event ends" : "{type} {time} после окончания события",
    "{type} at the event's start" : "{type} в момент начала события",
    "{type} at the event's end" : "{type} в момент окончания события",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Please enter a valid WebCal-URL" : "Пожалуйста, введите правильный адрес WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Серьезная ошибка в прокси webcal. Пожалуйста, обратитесь к администратору для получения дополнительной информации.",
    "Title of the Event" : "Название события",
    "Starts" : "Начинается",
    "Ends" : "Заканчивается",
    "All day Event" : "Событие на весь день",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "More ..." : "Больше ...",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Close" : "Закрыть",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Event status" : "Статус события",
    "Visibility when sharing" : "Видимость при общем доступе",
    "Export" : "Экспорт",
    "%s has published the calendar %s" : "%s опубликовал календарь %s",
    "Hello," : "Привет,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Хотим проинформировать, что %s опубликовал календарь {boldstart}%s{boldend}.",
    "Click here to access it" : "Нажмите здесь для получения доступа",
    "Cheers!" : "Удачи!",
    "We wanted to inform you that %s has published the calendar %s." : "Хотим проинформировать, что %s опубликовал календарь %s",
    "Click on the link below to access it" : "Нажмите на ссылку ниже для получения доступа",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Из-за присутствующей в разрабатываемой версии ошибки, календарь в настоящее время не в состоянии обеспечить поддержку функции конвейера asset.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Пожалуйста свяжитесь с администратором и попросите отключить опцию \"asset-pipeline.enabled\"",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Today" : "Сегодня",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Некоторые события в этом календаре испорчены. Пожалуйста проверьте консоль JS для получения дополнительной информации.",
    "Share Calendar" : "Поделиться календарём",
    "Shared" : "Общий доступ",
    "More" : "Больше",
    "Edit" : "Редактировать",
    "Link" : "Ссылка",
    "iCal link" : "Ссылка iCal",
    "Download" : "Скачать",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "can edit" : "можно редактировать",
    "Share link" : "Поделиться ссылкой",
    "Public access" : "Открытый доступ",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send" : "Отправить",
    "New Calendar" : "Новый Календарь",
    "Name" : "Название",
    "New Subscription" : "Новая подписка",
    "Go back" : "Назад",
    "Go forward" : "Вперед",
    "Calendar does not exist" : "Календарь не существует",
    "Maybe you got a wrong link or the calendar was unshared?" : "Вероятно, неверная ссылка или общий доступ к календарю был закрыт.",
    "Edit event" : "Редактировать событие",
    "Delete Event" : "Удалить событие",
    "Save Event" : "Сохранить событие",
    "Time" : "Время",
    "Type" : "Тип",
    "Relative" : "Относительно",
    "Absolute" : "В заданное время",
    "Repeat" : "Повтор",
    "times every" : "раз каждые",
    "Add" : "Добавить",
    "E-Mail address of attendee" : "Адрес электронной почты участника",
    "Please add your email address in the personal settings in order to add attendees." : "Пожалуйста, добавьте свой адрес электронной почты в личных настройках, чтобы пригласить участников.",
    "from" : "из",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Повторяющееся правило этого события пока не поддерживается.",
    "Support for advanced rules will be added with subsequent updates." : "Поддержка расширенных правил будут добавлены с последующими обновлениями.",
    "Reset repeating rule" : "Сбросить правила повтора",
    "Repeat every ..." : "Повторять каждые ...",
    "end repeat ..." : "конец повтора ...",
    "times" : "раз",
    "Import Calendars" : "Импорт календарей",
    "Import canceled" : "Импорт отменён",
    "Analyzing calendar" : "Анализ календарей",
    "The file contains objects incompatible with the selected calendar" : "Файл содержит объекты, которые не совместимы с выбранным календарем",
    "New calendar" : "Новый календарь",
    "File is empty" : "Файл пуст",
    "Import scheduled" : "Импорт запланирован",
    "%s shared the calendar <strong>%s</strong> with you" : "%s поделился с вами календарём  <strong>%s</strong> ",
    "Embed" : "Встроить",
    "IFrame to integrate" : "Iframe для встраивания",
    "Publish URL" : "Опубликовать URL",
    "Settings & import" : "Настройки и импорт",
    "Skip simple event editor" : "Не использовать простой редактор события",
    "Show week numbers" : "Показывать номера недель",
    "Import calendar" : "Импорт календаря",
    "No Calendars selected for import" : "Не выбраны календари для импорта",
    "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV",
    "Subscribe" : "Подписаться"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ru.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календарь",
    "%s has published the calendar »%s«" : "%s опубликовал календарь »%s«",
    "Hello," : "Привет,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Хотим сообщить, что %s опубликовал календарь %s«.",
    "Open »%s«" : "Открыть »%s«",
    "Cheers!" : "Удачи!",
    "Recipient" : "Получатель",
    "Too many redirects. Aborting ..." : "Очень много перенаправлений. Отмена...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Удалённый сервер не предоставил нам доступ к календарю (ошибка HTTP {%s})",
    "Error connecting to remote server" : "Ошибка подключения к удаленному серверу",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ошибка запроса ресурса на удаленном сервере. Это может  быть связано с несовпадением сертификата.",
    "Error requesting resource on remote server" : "Ошибка запроса ресурса на удалённом сервере",
    "Individual" : "Личность",
    "Group" : "Группа",
    "Resource" : "Ресурс",
    "Room" : "Комната",
    "Unknown" : "Неизвестно",
    "Required" : "Обязательно",
    "Optional" : "Не обязательно",
    "Does not attend" : "Без посещения",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вы находитесь в неизвестном часовом поясе ({tz}), возвращаемся к UTC",
    "Please create a calendar first." : "Пожалуйста, создайте сначала календарь.",
    "New event" : "Новое событие",
    "CalDAV address for clients" : "Адрес CalDAV  для клиентов",
    "Error saving WebCal-calendar" : "Ошибка при сохранении календаря WebCal",
    "WebDAV address for subscriptions" : "Адрес WebDAV для подписок",
    "Email has been sent." : "E-mail был отправлен.",
    "There was an issue while sending your email." : "Произошла ошибка при отправке вашего сообщения.",
    "group" : "группа",
    "Details" : "Подробно",
    "Attendees" : "Участники",
    "Reminders" : "Напоминания",
    "Repeating" : "Повторение",
    "When shared show full event" : "Показывать подробно при размещении в общем доступе",
    "When shared show only busy" : "Показывать только занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "Confirmed" : "Подтверждено",
    "Tentative" : "Под вопросом",
    "Cancelled" : "Отменено",
    "Please add a title." : "Добавьте заголовок.",
    "Please select a calendar." : "Выберите календарь.",
    "The event can not end before it starts." : "Событие не может завершаться раньше начала.",
    "Global" : "Основные",
    "None" : "Отсутствует",
    "Every day" : "Каждый день",
    "Every week" : "Каждую неделю",
    "Every month" : "Каждый месяц",
    "Every year" : "Каждый год",
    "never" : "никогда",
    "after" : "после",
    "How about getting started by importing some calendars?" : "Начнем с импорта календарей?",
    "At time of event" : "Во время события",
    "5 minutes before" : "За 5 минут до начала",
    "10 minutes before" : "За 10 минут до начала",
    "15 minutes before" : "За 15 минут до начала",
    "30 minutes before" : "За 30 минут до начала",
    "1 hour before" : "За 1 час до начала",
    "2 hours before" : "За 2 часа до начала",
    "Custom" : "Свои настройки",
    "Audio" : "Звук",
    "Email" : "Эл. почта",
    "Pop-up" : "Всплывающее окно",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "часов",
    "days" : "дней",
    "week" : "неделя",
    "before" : "до",
    "start" : "начала",
    "end" : "окончания",
    "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Successfully imported" : "Успешно импортировано",
    "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
    "Partially imported, {n} failures" : "Частично импортировано, {n} ошибок",
    "Audio alarm" : "Звуковой сигнал",
    "{type} {time} before the event starts" : "{type} {time} до начала события",
    "{type} {time} before the event ends" : "{type} {time} до окончания события",
    "{type} {time} after the event starts" : "{type} {time} после начала события",
    "{type} {time} after the event ends" : "{type} {time} после окончания события",
    "{type} at the event's start" : "{type} в момент начала события",
    "{type} at the event's end" : "{type} в момент окончания события",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Please enter a valid WebCal-URL" : "Пожалуйста, введите правильный адрес WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Серьезная ошибка в прокси webcal. Пожалуйста, обратитесь к администратору для получения дополнительной информации.",
    "Title of the Event" : "Название события",
    "Starts" : "Начинается",
    "Ends" : "Заканчивается",
    "All day Event" : "Событие на весь день",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "More ..." : "Больше ...",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Close" : "Закрыть",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Event status" : "Статус события",
    "Visibility when sharing" : "Видимость при общем доступе",
    "Export" : "Экспорт",
    "%s has published the calendar %s" : "%s опубликовал календарь %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Хотим проинформировать, что %s опубликовал календарь {boldstart}%s{boldend}.",
    "Click here to access it" : "Нажмите здесь для получения доступа",
    "We wanted to inform you that %s has published the calendar %s." : "Хотим проинформировать, что %s опубликовал календарь %s",
    "Click on the link below to access it" : "Нажмите на ссылку ниже для получения доступа",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Today" : "Сегодня",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Некоторые события в этом календаре испорчены. Пожалуйста проверьте консоль JS для получения дополнительной информации.",
    "Share Calendar" : "Поделиться календарём",
    "Shared" : "Общий доступ",
    "More" : "Больше",
    "Edit" : "Редактировать",
    "Link" : "Ссылка",
    "iCal link" : "Ссылка iCal",
    "Download" : "Скачать",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "can edit" : "можно редактировать",
    "Share link" : "Поделиться ссылкой",
    "Public access" : "Открытый доступ",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send" : "Отправить",
    "New Calendar" : "Новый Календарь",
    "Name" : "Название",
    "New Subscription" : "Новая подписка",
    "Go back" : "Назад",
    "Go forward" : "Вперед",
    "Calendar does not exist" : "Календарь не существует",
    "Maybe you got a wrong link or the calendar was unshared?" : "Вероятно, неверная ссылка или общий доступ к календарю был закрыт.",
    "Edit event" : "Редактировать событие",
    "Delete Event" : "Удалить событие",
    "Save Event" : "Сохранить событие",
    "Time" : "Время",
    "Type" : "Тип",
    "Relative" : "Относительно",
    "Absolute" : "В заданное время",
    "Repeat" : "Повтор",
    "times every" : "раз каждые",
    "Add" : "Добавить",
    "Email address of attendee" : "Адрес электронной почты участника",
    "Please add your email address in the personal settings in order to add attendees." : "Пожалуйста, добавьте свой адрес электронной почты в личных настройках, чтобы пригласить участников.",
    "from" : "из",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Повторяющееся правило этого события пока не поддерживается.",
    "Support for advanced rules will be added with subsequent updates." : "Поддержка расширенных правил будут добавлены с последующими обновлениями.",
    "Reset repeating rule" : "Сбросить правила повтора",
    "Repeat every ..." : "Повторять каждые ...",
    "end repeat ..." : "конец повтора ...",
    "times" : "раз",
    "Import Calendars" : "Импорт календарей",
    "Import canceled" : "Импорт отменён",
    "Analyzing calendar" : "Анализ календарей",
    "The file contains objects incompatible with the selected calendar" : "Файл содержит объекты, которые не совместимы с выбранным календарем",
    "New calendar" : "Новый календарь",
    "File is empty" : "Файл пуст",
    "Import scheduled" : "Импорт запланирован",
    "%s shared the calendar <strong>%s</strong> with you" : "%s поделился с вами календарём  <strong>%s</strong> ",
    "Embed" : "Встроить",
    "Iframe to integrate" : "Iframe для встраивания",
    "Publish URL" : "Опубликовать URL",
    "Settings & import" : "Настройки и импорт",
    "Skip simple event editor" : "Не использовать простой редактор события",
    "Show week numbers" : "Показывать номера недель",
    "Import calendar" : "Импорт календаря",
    "No Calendars selected for import" : "Не выбраны календари для импорта",
    "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV",
    "Subscribe" : "Подписаться"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
